Django Roles
===================


## Installation
Install the package

```bash
    $ pip install django-roles
```

## Dependencies
    
    django
    django-mptt


##Testing


Run all tests:
```bash
    $ python -m unittest discover -s tests -p '*_test.py'
```

Start test with nose and code coverage:
```bash
    $ nosetests --with-cov  --cov-report html  --cov  django-auth tests/
```


